@@ -1,6 +1,6 @@
 package Net::SFTP::Foreign::Constants;
 
-our $VERSION = '1.63_05';
+our $VERSION = '1.30';
 
 use strict;
 use warnings;
@@ -71,8 +71,7 @@ BEGIN {
 		      SFTP_ERR_REMOTE_STAT_FAILED => 1,
 		      SFTP_ERR_REMOTE_OPEN_FAILED => 2,
 		      SFTP_ERR_LOCAL_ALREADY_EXISTS => 3,
-		      # SFTP_ERR_LOCAL_OPEN_FAILED => 4,
-		      SFTP_ERR_LOCAL_OPEN_FAILED => 26,
+		      SFTP_ERR_LOCAL_OPEN_FAILED => 4,
 		      SFTP_ERR_REMOTE_READ_FAILED => 5,
 		      SFTP_ERR_REMOTE_BLOCK_TOO_SMALL => 6,
 		      SFTP_ERR_LOCAL_WRITE_FAILED => 7,
@@ -93,6 +92,7 @@ BEGIN {
 		      SFTP_ERR_REMOTE_RMDIR_FAILED => 23,
 		      SFTP_ERR_REMOTE_SETSTAT_FAILED => 24,
 		      SFTP_ERR_REMOTE_FSETSTAT_FAILED => 25,
+		      SFTP_ERR_LOCAL_OPEN_FAILED => 26,
 		      SFTP_ERR_LOCAL_STAT_FAILED => 27,
 		      SFTP_ERR_LOCAL_READ_ERROR => 28,
 		      SFTP_ERR_REMOTE_READDIR_FAILED => 29,
@@ -116,9 +116,6 @@ BEGIN {
                       SFTP_ERR_LOCAL_SEEK_FAILED => 47,
                       SFTP_ERR_REMOTE_STATVFS_FAILED => 48,
                       SFTP_ERR_REMOTE_FSTATVFS_FAILED => 49,
-		      SFTP_ERR_PASSWORD_AUTHENTICATION_FAILED => 50,
-                      SFTP_ERR_REMOTE_HARDLINK_FAILED => 51,
-		      SFTP_ERR_LOCAL_RENAME_FAILED => 52,
                     );
 
     for my $key (keys %constants) {
@@ -217,9 +214,8 @@ C<SFTP_ERR_REMOTE_READDIR_FAILED>, C<SFTP_ERR_REMOTE_READ_FAILED>,
 C<SFTP_ERR_REMOTE_REALPATH_FAILED>, C<SFTP_ERR_REMOTE_REMOVE_FAILED>,
 C<SFTP_ERR_REMOTE_RENAME_FAILED>, C<SFTP_ERR_REMOTE_RMDIR_FAILED>,
 C<SFTP_ERR_REMOTE_READLINK_FAILED>, C<SFTP_ERR_REMOTE_SYMLINK_FAILED>,
-C<SFTP_ERR_REMOTE_SETSTAT_FAILED>, C<SFTP_ERR_REMOTE_STAT_FAILED>,
-C<SFTP_ERR_REMOTE_WRITE_FAILED> and
-C<SFTP_ERR_REMOTE_HARDLINK_FAILED>.
+C<SFTP_ERR_REMOTE_SETSTAT_FAILED>, C<SFTP_ERR_REMOTE_STAT_FAILED> and
+C<SFTP_ERR_REMOTE_WRITE_FAILED>.
 
 Note: these constants are not defined on the SFTP draft.
 
